@@ -43,14 +43,7 @@ class TartufoCLI(click.MultiCommand):
 @click.command(
     cls=TartufoCLI,
     name="tartufo",
-    context_settings=dict(help_option_names=["-h", "--help"]),
-)
-@click.option(
-    "--rules",
-    multiple=True,
-    type=click.File("r"),
-    help="[DEPRECATED] Use the rule-patterns config options instead. Path(s) to regex "
-    "rules json list file(s).",
+    context_settings={"help_option_names": ["-h", "--help"]},
 )
 @click.option(
     "--rule-patterns",
@@ -127,8 +120,8 @@ class TartufoCLI(click.MultiCommand):
     ),
     default="text",
     help="""Specify the format in which the output needs to be generated
-    `--output-format json/compact/text`. Either `json`, `compact` or `text`
-    can be specified. If not provided (default) the output will be generated
+    `--output-format json/compact/text`. Either `json`, `compact`, `text`
+    or `report` can be specified. If not provided (default) the output will be generated
     in `text` format.""",
 )
 @click.option(
@@ -250,24 +243,6 @@ class TartufoCLI(click.MultiCommand):
     Decreasing the scanner's sensitivity increases the likelihood that a given
     string will be identified as suspicious.""",
 )
-@click.option(
-    "-b64",
-    "--b64-entropy-score",
-    help="""[DEPRECATED] Use `--entropy-sensitivity`. Modify the base64 entropy score. If
-    a value greater than the default (4.5 in a range of 0.0-6.0) is specified,
-    tartufo lists higher entropy base64 strings (longer or more randomized strings.
-    A lower value lists lower entropy base64 strings (shorter or less randomized
-    strings).""",
-)
-@click.option(
-    "-hex",
-    "--hex-entropy-score",
-    help="""[DEPRECATED] Use `--entropy-sensitivity`. Modify the hexadecimal entropy score.
-    If a value greater than the default (3.0 in a range of 0.0-4.0) is specified,
-    tartufo lists higher entropy hexadecimal strings (longer or more randomized
-    strings). A lower value lists lower entropy hexadecimal strings (shorter or less
-    randomized strings).""",
-)
 # The first positional argument here would be a hard-coded version, hence the `None`
 @click.version_option(None, "-V", "--version")
 @click.pass_context
